
/* Include GL, GLU & GLUT */
#ifdef WIN32
#include <windows.h>
#include <GL/gl.h>
#include <GL/glu.h>
#include <GL/glut.h>
#endif

#ifdef __APPLE__
#include <OpenGL/gl.h>
#include <OpenGL/glu.h>
#include <GLUT/glut.h>
#endif

#ifdef linux
#include <GL/gl.h>
#include <GL/glu.h>
#include <GL/glut.h>
#endif

/* Include some standard stuff */
#include <stdio.h>
#include <stdlib.h>
#include <math.h>

int perspective=0;

/* Draw standard Axis */
void axes() {
	int i;

	/* Data for just the standandar X axis */
	/* Others will be permutation on coordinates */
	GLfloat axis[][3] =   {  { -1  , 0    , 0     },
						     { 1   , 0    , 0     },
						     { 0.9 , 0.1  , 0     },
						     { 0.9 , -0.1 , 0     },
							 { 1   , 0    , 0     },
						     { 0.9 , 0    , 0.1   },
						     { 0.9 , 0    ,  -0.1 },
						     { 1   , 0    ,   0   } };
			
	/* X axis */		
	glColor3ub(255, 0, 0);
	glBegin(GL_LINE_STRIP);
	//for(i=0;i<8;i++) glVertex3f(axis[i][0],axis[i][1],axis[i][2]);
	for(i=0;i<8;i++) glVertex3fv(axis[i]);
	glEnd();
	
	/* Y axis */
	glColor3ub(0, 255, 0);
	glBegin(GL_LINE_STRIP);
	for(i=0;i<8;i++) glVertex3f(axis[i][2],axis[i][0],axis[i][1]);
	glEnd();
	
	/* Z axis */
	glColor3ub(0, 0, 255);
	glBegin(GL_LINE_STRIP);
	for(i=0;i<8;i++) glVertex3f(axis[i][1],axis[i][2],axis[i][0]);
	glEnd();
	
}

/* Eye position */
void position() {
	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();
	gluLookAt( 2, 2, 2, 0, 0, 0, 0, 1, 0 );
}



void display(void) {
	/* Clear Buffer */
	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
	
	/* Position Eye */
	position();
	
	/* Draw model */
	axes();
	
	/* Start drawing if you haven't */
	glFlush();
}


void reshape(int w, int h) {	
	/* Current aspect ratio */
	float ratio=((float) w) / ((float) h);

	glViewport(0, 0, w, h);

	/* Projection Matrix */
	glMatrixMode(GL_PROJECTION);
	
	/* Load identity */
	glLoadIdentity();
	
	/* The projection */
	if (!perspective) {
		/* Orthografic */
		/* Keep 1:1 ratio, shortest side must be at least [-1,1] */
		if (ratio>1) glOrtho( -ratio, ratio, -1, 1, 1, 50);
		else glOrtho( -1, 1, -1/ratio, 1/ratio, 1, 50);
	} else {
		/* OR Perspective */
		gluPerspective(35, ratio, 1, 50 );
	}
	
	/* Redraw this window */
	glutPostRedisplay();
}


void keyboard(unsigned char key, int x, int y) {
	/* Things to remember between calls */
	static int fullscreen=0;
	static int old_w,old_h;
	static int old_x,old_y;
	switch(key) {
		/* Q or esc: Quit */
		case 27:
		case 'q':
		case 'Q':
			exit(0);
			break;
		/* F: Fullscreen toogle */
		case 'f':
		case 'F':
			/* Not in full screen */
			if (!fullscreen) {
				/* Save window size and position */
				old_w=glutGet(GLUT_WINDOW_WIDTH);			
				old_h=glutGet(GLUT_WINDOW_HEIGHT);
				old_x=glutGet(GLUT_WINDOW_X);
				old_y=glutGet(GLUT_WINDOW_Y);
				/* Go fullscreen */
				glutFullScreen();
				fullscreen=1;
			} else {
				/* Set window size and shape to original values */
				glutReshapeWindow(old_w, old_h);
				glutPositionWindow(old_x, old_y);
				fullscreen=0;
			}
			glutPostRedisplay();
			break;
		/* p: Perspective */
		case 'p':
		case 'P':
			perspective=1;
			/* Call reshape */
			reshape(glutGet(GLUT_WINDOW_WIDTH),  glutGet(GLUT_WINDOW_HEIGHT));
			glutPostRedisplay();
			break;
		case 'o':
		case 'O':
			perspective=0;
			reshape(glutGet(GLUT_WINDOW_WIDTH),  glutGet(GLUT_WINDOW_HEIGHT));
			glutPostRedisplay();
			break;
	}
}


int main (int argc, const char** argv) {

	/* Init Glut */
	glutInit(&argc, argv);
	
	/* Initial parameters */
	glutInitDisplayMode(GLUT_RGB | GLUT_DEPTH | GLUT_SINGLE);
	glutInitWindowSize(800, 600);
    glutInitWindowPosition(0, 0);
	
	/* Create main Window */
	glutCreateWindow("Axes");
	
	/* Set Callbacks */
	glutDisplayFunc(display);
	glutReshapeFunc(reshape);
	glutKeyboardFunc(keyboard);
    
	/* Glut Main Loop */
	glutMainLoop();

	/* Never reached, keep compiler happy */
	return 0;
}

